@@ -1,8 +1,8 @@
 from ZestyParser import *
 from sys import stdin
 
-T_TERM = CompositeToken(['T_MULTIPLICATIVE_EXPR', 'T_FACTOR'])
-T_EXPR = CompositeToken(['T_ADDITIVE_EXPR', T_TERM])
+T_TERM = Defer(lambda: T_MULTIPLICATIVE_EXPR) | Defer(lambda: T_FACTOR)
+T_EXPR = Defer(lambda: T_ADDITIVE_EXPR) | T_TERM
 
 T_PARENTHETICAL_EXPR = (RawToken('(') + T_EXPR + RawToken(')')) >> (lambda r: r[1])
 T_FACTOR = (T_PARENTHETICAL_EXPR | Token('[0-9]+', lambda m: int(m.group())))
@@ -18,5 +18,4 @@ T_ADDITIVE_EXPR = (
 )
 
 parser = ZestyParser(stdin.read())
-parser.addTokens(T_FACTOR=T_FACTOR, T_ADDITIVE_EXPR=T_ADDITIVE_EXPR, T_MULTIPLICATIVE_EXPR=T_MULTIPLICATIVE_EXPR)
 print parser.scan(T_EXPR)
\ No newline at end of file
