@@ -1,14 +1,13 @@
-from sexp import SexpParser
+from sexp import parse
 from sys import stdin
 from datetime import datetime
 
-parser = SexpParser()
 data = stdin.read()
 
 start_time = datetime.now()
 
-for i in range(1000):
-	parser.parse(data)
+for i in range(5000):
+	parse(data)
 
 end_time = datetime.now()
 
