@@ -3,8 +3,6 @@
 from ZestyParser import *
 import binascii, re, sys
 
-T_SPACE = Token(r'\s+')
-
 T_VERBATIM_STRING = Token(r'([0-9]+):', lambda p, m: p.scan(TakeToken(int(m.group(1))) ^ 'Not enough characters'))
 T_TOKEN_STRING = Token(r'[A-Za-z\-./_:*+=][0-9A-Za-z\-./_:*+=]*', ReturnRaw)
 T_BASE64_STRING = Token(r'\|([0-9A-Za-z+/=\s]*)\|', lambda m: binascii.a2b_base64(m.group(1)))
@@ -19,13 +17,7 @@ def T_QUOTED_STRING(r):
 	return re.sub(r'\\(.)', r'\1', text)
 
 T_STRING = T_VERBATIM_STRING | T_QUOTED_STRING | T_TOKEN_STRING | T_BASE64_STRING | T_HEX_STRING
-
-@CallbackFor(RawToken('('))
-def T_LIST(p, r):
-	o = list(p.iter(T_SEXP, skip=T_SPACE))
-	p.skip(RawToken(')') ^ 'Expected close paren or S-expression')
-	return o
-
+T_LIST = (RawToken('(') + TokenSeries(Defer(lambda: T_SEXP), skip=Token(r'\s+')) + (RawToken(')') ^ 'Expected close paren or S-expression')) >> (lambda r: r[1])
 T_SEXP = T_STRING | T_LIST
 
 def parse(string):
